# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AggregatedResponseItemRankWithUnitResponse(Model):
    """AggregatedResponseItemRankWithUnitResponse.

    :param period:
    :type period: ~energycap.sdk.models.PeriodRange
    :param total:
    :type total: ~energycap.sdk.models.ItemRankWithUnitResponse
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.ItemRankWithUnitResponse]
    """

    _attribute_map = {
        'period': {'key': 'period', 'type': 'PeriodRange'},
        'total': {'key': 'total', 'type': 'ItemRankWithUnitResponse'},
        'data_details': {'key': 'dataDetails', 'type': '[ItemRankWithUnitResponse]'},
    }

    def __init__(self, **kwargs):
        super(AggregatedResponseItemRankWithUnitResponse, self).__init__(**kwargs)
        self.period = kwargs.get('period', None)
        self.total = kwargs.get('total', None)
        self.data_details = kwargs.get('data_details', None)
