# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGScope(Model):
    """GHGScope.

    :param scope_id: The Scope Identifier
    :type scope_id: int
    :param scope_info: The Scope Info
    :type scope_info: str
    """

    _attribute_map = {
        'scope_id': {'key': 'scopeId', 'type': 'int'},
        'scope_info': {'key': 'scopeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGScope, self).__init__(**kwargs)
        self.scope_id = kwargs.get('scope_id', None)
        self.scope_info = kwargs.get('scope_info', None)
