# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceLinkResponse(Model):
    """EnergyStarPlaceLinkResponse.

    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param submit_mode: The submit mode. Could be "Meter" or "Commodity"
    :type submit_mode: str
    :param pm_property_id: una co
     The Portfolio Manager property identifier
    :type pm_property_id: long
    :param meters: List of meters for this place
    :type meters: list[~energycap.sdk.models.EnergyStarMeterLinkChild]
    :param commodities: List of commodities for this place
    :type commodities:
     list[~energycap.sdk.models.EnergyStarCommodityLinkChild]
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'submit_mode': {'key': 'submitMode', 'type': 'str'},
        'pm_property_id': {'key': 'pmPropertyId', 'type': 'long'},
        'meters': {'key': 'meters', 'type': '[EnergyStarMeterLinkChild]'},
        'commodities': {'key': 'commodities', 'type': '[EnergyStarCommodityLinkChild]'},
    }

    def __init__(self, *, place=None, submit_mode: str=None, pm_property_id: int=None, meters=None, commodities=None, **kwargs) -> None:
        super(EnergyStarPlaceLinkResponse, self).__init__(**kwargs)
        self.place = place
        self.submit_mode = submit_mode
        self.pm_property_id = pm_property_id
        self.meters = meters
        self.commodities = commodities
