# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterLinkRequest(Model):
    """MeterLinkRequest.

    :param meter_id: The identifier for a Meter.
     Set to null to remove the link. <span class='property-internal'>Topmost
     (Meter)</span> <span class='property-internal'>Required (defined)</span>
    :type meter_id: int
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
    }

    def __init__(self, *, meter_id: int=None, **kwargs) -> None:
        super(MeterLinkRequest, self).__init__(**kwargs)
        self.meter_id = meter_id
