# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGDefaultFactor(Model):
    """GHGDefaultFactor.

    All required parameters must be populated in order to send to Azure.

    :param factor_id: The Greenhouse Gas Factor identifier <span
     class='property-internal'>Required when FactorType is set to specific
     factor</span>
    :type factor_id: int
    :param factor_type: Required. The Greenhouse Gas Factor type.
     The valid values for this field are "use meter address" or "specific
     factor" <span class='property-internal'>Required</span> <span
     class='property-internal'>One of use meter address, specific factor
     </span>
    :type factor_type: str
    """

    _validation = {
        'factor_type': {'required': True},
    }

    _attribute_map = {
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'factor_type': {'key': 'factorType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGDefaultFactor, self).__init__(**kwargs)
        self.factor_id = kwargs.get('factor_id', None)
        self.factor_type = kwargs.get('factor_type', None)
