# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyCapOptionsEnergyCapIDOptions(Model):
    """EnergyCapOptionsEnergyCapIDOptions.

    :param base_url:
    :type base_url: str
    :param gateway_api_path:
    :type gateway_api_path: str
    """

    _attribute_map = {
        'base_url': {'key': 'baseUrl', 'type': 'str'},
        'gateway_api_path': {'key': 'gatewayApiPath', 'type': 'str'},
    }

    def __init__(self, *, base_url: str=None, gateway_api_path: str=None, **kwargs) -> None:
        super(EnergyCapOptionsEnergyCapIDOptions, self).__init__(**kwargs)
        self.base_url = base_url
        self.gateway_api_path = gateway_api_path
