# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AggregatedComparisonResponseGHGPerformanceComparison(Model):
    """AggregatedComparisonResponseGHGPerformanceComparison.

    :param period_range:
    :type period_range: ~energycap.sdk.models.PeriodRangeComparison
    :param total:
    :type total: ~energycap.sdk.models.GHGPerformanceComparison
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.GHGPerformanceComparison]
    """

    _attribute_map = {
        'period_range': {'key': 'periodRange', 'type': 'PeriodRangeComparison'},
        'total': {'key': 'total', 'type': 'GHGPerformanceComparison'},
        'data_details': {'key': 'dataDetails', 'type': '[GHGPerformanceComparison]'},
    }

    def __init__(self, *, period_range=None, total=None, data_details=None, **kwargs) -> None:
        super(AggregatedComparisonResponseGHGPerformanceComparison, self).__init__(**kwargs)
        self.period_range = period_range
        self.total = total
        self.data_details = data_details
