# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGScopeCategory(Model):
    """GHGScopeCategory.

    :param scope:
    :type scope: ~energycap.sdk.models.GHGScope
    :param scope_category_id: The GHG Scope Category Identifier
    :type scope_category_id: int
    :param scope_category_info: The GHG Scope Category Info
    :type scope_category_info: str
    :param scope_category_description: The GHG Scope Category Description
    :type scope_category_description: str
    """

    _attribute_map = {
        'scope': {'key': 'scope', 'type': 'GHGScope'},
        'scope_category_id': {'key': 'scopeCategoryId', 'type': 'int'},
        'scope_category_info': {'key': 'scopeCategoryInfo', 'type': 'str'},
        'scope_category_description': {'key': 'scopeCategoryDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGScopeCategory, self).__init__(**kwargs)
        self.scope = kwargs.get('scope', None)
        self.scope_category_id = kwargs.get('scope_category_id', None)
        self.scope_category_info = kwargs.get('scope_category_info', None)
        self.scope_category_description = kwargs.get('scope_category_description', None)
