# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestComparisonResponse(Model):
    """Comparison data for a place.

    :param current_period_range:
    :type current_period_range: ~energycap.sdk.models.PeriodRange
    :param previous_period_range:
    :type previous_period_range: ~energycap.sdk.models.PeriodRange
    :param intensity:
    :type intensity: ~energycap.sdk.models.ValueComparison
    :param total:
    :type total: ~energycap.sdk.models.ValueComparison
    :param commodities: Comparison values for each commodity
    :type commodities: list[~energycap.sdk.models.CommodityValueComparison]
    :param floor_area_unit:
    :type floor_area_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'current_period_range': {'key': 'currentPeriodRange', 'type': 'PeriodRange'},
        'previous_period_range': {'key': 'previousPeriodRange', 'type': 'PeriodRange'},
        'intensity': {'key': 'intensity', 'type': 'ValueComparison'},
        'total': {'key': 'total', 'type': 'ValueComparison'},
        'commodities': {'key': 'commodities', 'type': '[CommodityValueComparison]'},
        'floor_area_unit': {'key': 'floorAreaUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestComparisonResponse, self).__init__(**kwargs)
        self.current_period_range = kwargs.get('current_period_range', None)
        self.previous_period_range = kwargs.get('previous_period_range', None)
        self.intensity = kwargs.get('intensity', None)
        self.total = kwargs.get('total', None)
        self.commodities = kwargs.get('commodities', None)
        self.floor_area_unit = kwargs.get('floor_area_unit', None)
