# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeSeriesDataResponse(Model):
    """TimeSeriesDataResponse.

    :param entities:
    :type entities: list[~energycap.sdk.models.TimeSeriesEntity]
    :param values:
    :type values: list[~energycap.sdk.models.TimeSeriesValue]
    """

    _attribute_map = {
        'entities': {'key': 'entities', 'type': '[TimeSeriesEntity]'},
        'values': {'key': 'values', 'type': '[TimeSeriesValue]'},
    }

    def __init__(self, *, entities=None, values=None, **kwargs) -> None:
        super(TimeSeriesDataResponse, self).__init__(**kwargs)
        self.entities = entities
        self.values = values
