# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGGroupEmissions(Model):
    """GHGGroupEmissions.

    :param group_info: The name of the greenhouse gas.
    :type group_info: str
    :param total_emissions: The total emissions for this gas, in CO2
     Equivalent.
    :type total_emissions: float
    """

    _attribute_map = {
        'group_info': {'key': 'groupInfo', 'type': 'str'},
        'total_emissions': {'key': 'totalEmissions', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(GHGGroupEmissions, self).__init__(**kwargs)
        self.group_info = kwargs.get('group_info', None)
        self.total_emissions = kwargs.get('total_emissions', None)
