# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestSavingsMonthlyResponseResults(Model):
    """PlaceDigestSavingsMonthlyResponseResults.

    :param period_name: Calendar Period Name
    :type period_name: str
    :param calendar_period: Calendar Period
    :type calendar_period: int
    :param calendar_year: Calendar Year
    :type calendar_year: int
    :param fiscal_period: Fiscal Period
    :type fiscal_period: int
    :param fiscal_year: Fiscal Year
    :type fiscal_year: int
    :param savings_total_cost: Savings Total Cost
    :type savings_total_cost: float
    :param savings_global_use: Savings Global Use
    :type savings_global_use: float
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'savings_total_cost': {'key': 'savingsTotalCost', 'type': 'float'},
        'savings_global_use': {'key': 'savingsGlobalUse', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestSavingsMonthlyResponseResults, self).__init__(**kwargs)
        self.period_name = kwargs.get('period_name', None)
        self.calendar_period = kwargs.get('calendar_period', None)
        self.calendar_year = kwargs.get('calendar_year', None)
        self.fiscal_period = kwargs.get('fiscal_period', None)
        self.fiscal_year = kwargs.get('fiscal_year', None)
        self.savings_total_cost = kwargs.get('savings_total_cost', None)
        self.savings_global_use = kwargs.get('savings_global_use', None)
