# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PermissionProduct(Model):
    """PermissionProduct.

    :param product_id:
    :type product_id: int
    :param product_code:
    :type product_code: str
    :param product_info:
    :type product_info: str
    """

    _attribute_map = {
        'product_id': {'key': 'productId', 'type': 'int'},
        'product_code': {'key': 'productCode', 'type': 'str'},
        'product_info': {'key': 'productInfo', 'type': 'str'},
    }

    def __init__(self, *, product_id: int=None, product_code: str=None, product_info: str=None, **kwargs) -> None:
        super(PermissionProduct, self).__init__(**kwargs)
        self.product_id = product_id
        self.product_code = product_code
        self.product_info = product_info
