# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TargetSettings(Model):
    """TargetSettings.

    :param label: Target line label
    :type label: str
    :param base_year: Target line base year
    :type base_year: int
    :param cost_target:
    :type cost_target: ~energycap.sdk.models.Target
    :param use_target:
    :type use_target: ~energycap.sdk.models.Target
    :param ghg_target:
    :type ghg_target: ~energycap.sdk.models.Target
    """

    _attribute_map = {
        'label': {'key': 'label', 'type': 'str'},
        'base_year': {'key': 'baseYear', 'type': 'int'},
        'cost_target': {'key': 'costTarget', 'type': 'Target'},
        'use_target': {'key': 'useTarget', 'type': 'Target'},
        'ghg_target': {'key': 'ghgTarget', 'type': 'Target'},
    }

    def __init__(self, *, label: str=None, base_year: int=None, cost_target=None, use_target=None, ghg_target=None, **kwargs) -> None:
        super(TargetSettings, self).__init__(**kwargs)
        self.label = label
        self.base_year = base_year
        self.cost_target = cost_target
        self.use_target = use_target
        self.ghg_target = ghg_target
