# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Icon(Model):
    """Icon.

    :param code: The icon code <span class='property-internal'>Must be between
     0 and 64 characters</span>
    :type code: str
    :param color: The icon color <span class='property-internal'>Must be
     between 0 and 32 characters</span>
    :type color: str
    """

    _validation = {
        'code': {'max_length': 64, 'min_length': 0},
        'color': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'color': {'key': 'color', 'type': 'str'},
    }

    def __init__(self, *, code: str=None, color: str=None, **kwargs) -> None:
        super(Icon, self).__init__(**kwargs)
        self.code = code
        self.color = color
