# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettings(Model):
    """EnergyStarSettings.

    :param submit_by_commodity_only: Indicates to always configure ENERGY STAR
     on a per commodity basis
    :type submit_by_commodity_only: bool
    """

    _attribute_map = {
        'submit_by_commodity_only': {'key': 'submitByCommodityOnly', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarSettings, self).__init__(**kwargs)
        self.submit_by_commodity_only = kwargs.get('submit_by_commodity_only', None)
