# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityLinkChild(Model):
    """EnergyStarCommodityLinkChild.

    :param pm_meter_id: The Portfolio Manager meter identifier
    :type pm_meter_id: long
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param energy_star_compatible: Indicates if the commodity is compatible
     with ENERGY STAR
    :type energy_star_compatible: bool
    """

    _attribute_map = {
        'pm_meter_id': {'key': 'pmMeterId', 'type': 'long'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'energy_star_compatible': {'key': 'energyStarCompatible', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarCommodityLinkChild, self).__init__(**kwargs)
        self.pm_meter_id = kwargs.get('pm_meter_id', None)
        self.commodity = kwargs.get('commodity', None)
        self.energy_star_compatible = kwargs.get('energy_star_compatible', None)
