# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionSourceLink(Model):
    """EmissionSourceLink.

    :param emission_source_id: The identifier for an Emission source.
    :type emission_source_id: int
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(EmissionSourceLink, self).__init__(**kwargs)
        self.emission_source_id = kwargs.get('emission_source_id', None)
