# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGTargetEmissions(Model):
    """GHGTargetEmissions.

    :param base_target_year:
    :type base_target_year: ~energycap.sdk.models.GHGYearlyEmissions
    :param adjusted_target_year:
    :type adjusted_target_year: ~energycap.sdk.models.GHGYearlyEmissions
    :param adjusted_ytd_target_year:
    :type adjusted_ytd_target_year: ~energycap.sdk.models.GHGYearlyEmissions
    """

    _attribute_map = {
        'base_target_year': {'key': 'baseTargetYear', 'type': 'GHGYearlyEmissions'},
        'adjusted_target_year': {'key': 'adjustedTargetYear', 'type': 'GHGYearlyEmissions'},
        'adjusted_ytd_target_year': {'key': 'adjustedYTDTargetYear', 'type': 'GHGYearlyEmissions'},
    }

    def __init__(self, *, base_target_year=None, adjusted_target_year=None, adjusted_ytd_target_year=None, **kwargs) -> None:
        super(GHGTargetEmissions, self).__init__(**kwargs)
        self.base_target_year = base_target_year
        self.adjusted_target_year = adjusted_target_year
        self.adjusted_ytd_target_year = adjusted_ytd_target_year
