# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeSeriesValue(Model):
    """TimeSeriesValue.

    :param id:
    :type id: int
    :param formatted_value:
    :type formatted_value: str
    :param date_property:
    :type date_property: datetime
    :param value:
    :type value: float
    :param unit:
    :type unit: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'formatted_value': {'key': 'formattedValue', 'type': 'str'},
        'date_property': {'key': 'date', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TimeSeriesValue, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.formatted_value = kwargs.get('formatted_value', None)
        self.date_property = kwargs.get('date_property', None)
        self.value = kwargs.get('value', None)
        self.unit = kwargs.get('unit', None)
