# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CollectionEmissionSourceChild(Model):
    """CollectionEmissionSourceChild.

    :param emission_source_id: The emission source identifier
    :type emission_source_id: int
    :param emission_source_code: The emission source code
    :type emission_source_code: str
    :param emission_source_info: The emission source info
    :type emission_source_info: str
    :param active: Whether the emission source is active or not
    :type active: bool
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
        'emission_source_code': {'key': 'emissionSourceCode', 'type': 'str'},
        'emission_source_info': {'key': 'emissionSourceInfo', 'type': 'str'},
        'active': {'key': 'active', 'type': 'bool'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
    }

    def __init__(self, **kwargs):
        super(CollectionEmissionSourceChild, self).__init__(**kwargs)
        self.emission_source_id = kwargs.get('emission_source_id', None)
        self.emission_source_code = kwargs.get('emission_source_code', None)
        self.emission_source_info = kwargs.get('emission_source_info', None)
        self.active = kwargs.get('active', None)
        self.commodity = kwargs.get('commodity', None)
