# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorRegion(Model):
    """GHGFactorRegion.

    :param factor_region_id: The Factor Region identifier
    :type factor_region_id: int
    :param factor_region_info: The Factor Region info
    :type factor_region_info: str
    """

    _attribute_map = {
        'factor_region_id': {'key': 'factorRegionId', 'type': 'int'},
        'factor_region_info': {'key': 'factorRegionInfo', 'type': 'str'},
    }

    def __init__(self, *, factor_region_id: int=None, factor_region_info: str=None, **kwargs) -> None:
        super(GHGFactorRegion, self).__init__(**kwargs)
        self.factor_region_id = factor_region_id
        self.factor_region_info = factor_region_info
