# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WatticsDataPoint(Model):
    """WatticsDataPoint.

    :param wattics_data_point_id: The identifier for a Wattics meter
    :type wattics_data_point_id: int
    """

    _attribute_map = {
        'wattics_data_point_id': {'key': 'watticsDataPointId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(WatticsDataPoint, self).__init__(**kwargs)
        self.wattics_data_point_id = kwargs.get('wattics_data_point_id', None)
