# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FailedReadings(Model):
    """FailedReadings.

    :param time:
    :type time: datetime
    :param value:
    :type value: float
    :param estimated:
    :type estimated: bool
    :param note:
    :type note: str
    :param error:
    :type error: str
    """

    _attribute_map = {
        'time': {'key': 'time', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'note': {'key': 'note', 'type': 'str'},
        'error': {'key': 'error', 'type': 'str'},
    }

    def __init__(self, *, time=None, value: float=None, estimated: bool=None, note: str=None, error: str=None, **kwargs) -> None:
        super(FailedReadings, self).__init__(**kwargs)
        self.time = time
        self.value = value
        self.estimated = estimated
        self.note = note
        self.error = error
