# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionSourceLinkRequest(Model):
    """EmissionSourceLinkRequest.

    :param emission_source_id: The identifier for an Emission source.
     Set to null to remove the link. <span class='property-internal'>Topmost
     (EmissionSource)</span> <span class='property-internal'>Required
     (defined)</span>
    :type emission_source_id: int
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
    }

    def __init__(self, *, emission_source_id: int=None, **kwargs) -> None:
        super(EmissionSourceLinkRequest, self).__init__(**kwargs)
        self.emission_source_id = emission_source_id
