# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UtilityPlatform(Model):
    """UtilityPlatform.

    :param data_release_file_url: Date Release file Url used to record Data
     access release
    :type data_release_file_url: str
    :param utility_platform_provider_key: Identifier for the Utility Platform
     Provider Organization
    :type utility_platform_provider_key: str
    :param utility_platform_provider_info: Name of the Utility Platform
     Provider Organization
    :type utility_platform_provider_info: str
    :param can_decline_data_release: Flag to indicate if Data Release requests
     from this Utility Provider can be declined
    :type can_decline_data_release: bool
    """

    _attribute_map = {
        'data_release_file_url': {'key': 'dataReleaseFileUrl', 'type': 'str'},
        'utility_platform_provider_key': {'key': 'utilityPlatformProviderKey', 'type': 'str'},
        'utility_platform_provider_info': {'key': 'utilityPlatformProviderInfo', 'type': 'str'},
        'can_decline_data_release': {'key': 'canDeclineDataRelease', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(UtilityPlatform, self).__init__(**kwargs)
        self.data_release_file_url = kwargs.get('data_release_file_url', None)
        self.utility_platform_provider_key = kwargs.get('utility_platform_provider_key', None)
        self.utility_platform_provider_info = kwargs.get('utility_platform_provider_info', None)
        self.can_decline_data_release = kwargs.get('can_decline_data_release', None)
