# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityCategory(Model):
    """CommodityCategory.

    :param commodity_category_id: The commodity category id
    :type commodity_category_id: int
    :param commodity_category_info: The commodity category info
    :type commodity_category_info: str
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param common_demand_unit:
    :type common_demand_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'commodity_category_id': {'key': 'commodityCategoryId', 'type': 'int'},
        'commodity_category_info': {'key': 'commodityCategoryInfo', 'type': 'str'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'common_demand_unit': {'key': 'commonDemandUnit', 'type': 'UnitChild'},
    }

    def __init__(self, *, commodity_category_id: int=None, commodity_category_info: str=None, common_use_unit=None, common_demand_unit=None, **kwargs) -> None:
        super(CommodityCategory, self).__init__(**kwargs)
        self.commodity_category_id = commodity_category_id
        self.commodity_category_info = commodity_category_info
        self.common_use_unit = common_use_unit
        self.common_demand_unit = common_demand_unit
